@@ -1,16 +1,13 @@
 from re import match
-from typing import List
 
 from selenium.webdriver.common.by import By
-from selenium.common.exceptions import NoSuchElementException, TimeoutException
-from selenium.webdriver.remote.webelement import WebElement
 from selen_kaa.utils import custom_types
 
 
 TimeoutType = custom_types.TimeoutType
 
 
-def get_selector_type(selector):
+def get_selector_type(selector: str):
     """ Checks if selector is css or xpath
     >>>get_selector_type(".css")
     css selector
